==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storsimple/kotlin/inputs/GetBackupSchedulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storsimple.kotlin.inputs

import com.pulumi.azurenative.storsimple.inputs.GetBackupSchedulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property backupPolicyName The backup policy name.
 * @property backupScheduleName The name of the backup schedule to be fetched
 * @property deviceName The device name
 * @property managerName The manager name
 * @property resourceGroupName The resource group name
 */
public data class GetBackupSchedulePlainArgs(
    public val backupPolicyName: String,
    public val backupScheduleName: String,
    public val deviceName: String,
    public val managerName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.storsimple.inputs.GetBackupSchedulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.storsimple.inputs.GetBackupSchedulePlainArgs =
        com.pulumi.azurenative.storsimple.inputs.GetBackupSchedulePlainArgs.builder()
            .backupPolicyName(backupPolicyName.let({ args0 -> args0 }))
            .backupScheduleName(backupScheduleName.let({ args0 -> args0 }))
            .deviceName(deviceName.let({ args0 -> args0 }))
            .managerName(managerName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBackupSchedulePlainArgs].
 */
@PulumiTagMarker
public class GetBackupSchedulePlainArgsBuilder internal constructor() {
    private var backupPolicyName: String? = null

    private var backupScheduleName: String? = null

    private var deviceName: String? = null

    private var managerName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The backup policy name.
     */
    @JvmName("wxuvqjxwlqkbuovo")
    public suspend fun backupPolicyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.backupPolicyName = mapped
    }

    /**
     * @param value The name of the backup schedule to be fetched
     */
    @JvmName("gtqnhlaujsucbdju")
    public suspend fun backupScheduleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.backupScheduleName = mapped
    }

    /**
     * @param value The device name
     */
    @JvmName("ulndgiccvatyntpg")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The manager name
     */
    @JvmName("ginhhqvkubdjlrlg")
    public suspend fun managerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.managerName = mapped
    }

    /**
     * @param value The resource group name
     */
    @JvmName("hbcbfnuxgrwbjimk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetBackupSchedulePlainArgs = GetBackupSchedulePlainArgs(
        backupPolicyName = backupPolicyName ?: throw PulumiNullFieldException("backupPolicyName"),
        backupScheduleName = backupScheduleName ?: throw PulumiNullFieldException("backupScheduleName"),
        deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
        managerName = managerName ?: throw PulumiNullFieldException("managerName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storsimple/kotlin/inputs/GetBackupSchedulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storsimple.kotlin.inputs

import com.pulumi.azurenative.storsimple.inputs.GetBackupSchedulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property backupPolicyName The backup policy name.
 * @property backupScheduleName The name of the backup schedule to be fetched
 * @property deviceName The device name
 * @property managerName The manager name
 * @property resourceGroupName The resource group name
 */
public data class GetBackupSchedulePlainArgs(
    public val backupPolicyName: String,
    public val backupScheduleName: String,
    public val deviceName: String,
    public val managerName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.storsimple.inputs.GetBackupSchedulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.storsimple.inputs.GetBackupSchedulePlainArgs =
        com.pulumi.azurenative.storsimple.inputs.GetBackupSchedulePlainArgs.builder()
            .backupPolicyName(backupPolicyName.let({ args0 -> args0 }))
            .backupScheduleName(backupScheduleName.let({ args0 -> args0 }))
            .deviceName(deviceName.let({ args0 -> args0 }))
            .managerName(managerName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBackupSchedulePlainArgs].
 */
@PulumiTagMarker
public class GetBackupSchedulePlainArgsBuilder internal constructor() {
    private var backupPolicyName: String? = null

    private var backupScheduleName: String? = null

    private var deviceName: String? = null

    private var managerName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The backup policy name.
     */
    @JvmName("iictbysmnrkkglqd")
    public suspend fun backupPolicyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.backupPolicyName = mapped
    }

    /**
     * @param value The name of the backup schedule to be fetched
     */
    @JvmName("gvqmniowviqmcnug")
    public suspend fun backupScheduleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.backupScheduleName = mapped
    }

    /**
     * @param value The device name
     */
    @JvmName("bwnwrwieoblkecjc")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The manager name
     */
    @JvmName("demqoxewvbdrlgvo")
    public suspend fun managerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.managerName = mapped
    }

    /**
     * @param value The resource group name
     */
    @JvmName("mrkixtqlitulpktf")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetBackupSchedulePlainArgs = GetBackupSchedulePlainArgs(
        backupPolicyName = backupPolicyName ?: throw PulumiNullFieldException("backupPolicyName"),
        backupScheduleName = backupScheduleName ?: throw PulumiNullFieldException("backupScheduleName"),
        deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
        managerName = managerName ?: throw PulumiNullFieldException("managerName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
